@@ -1,10 +1,12 @@
 #! /usr/bin/env python
+
 # -*- coding: utf-8 -*-
 
 """ This is a Qt Gui file for pyKake. """
+""" The version 0.7.3 will include new remote control file. It is only for Sony and Minolta, but may also work with other manufacturers too (Or not). """
 
 APP_TITLE="pyKake"
-APP_VERSION="0.7.2"
+APP_VERSION="0.7.3"
 LOGO = '/opt/pykake/pykake.png'
 BUGTRACKER= "http://talk.maemo.org/showthread.php?t=50204"
 
@@ -55,23 +57,23 @@ sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding) # Size po
 
 class MainWindow(QMainWindow): # Class for main application
 	def __init__(self):
-		print "Intializing Main..."
+		# print "Intializing Main..."
 		QMainWindow.__init__(self, None)		 # Intializing the main window
 		self.mapper = QSignalMapper() # Intializing the Signal mapper for the program
 		
 		# Collecting settings for app, if this is first run
-		print "Check that settings has been set..."
+		# print "Check that settings has been set..."
 		if CURRENT_REMOTETYPE == "None" or TIME2BEEB == "None":
 			self.settingsDialog()
 			
 		self.resize(800, 480)
-		print "Reading style..."
+		# print "Reading style..."
 		self.setStyleSheet(MiscFunctions().readFile(styleFile))
 		self.setWindowTitle("%s %s" %(APP_TITLE, APP_VERSION))
 		
 		# Creating menu buttons:
 		if USEFULLSCREEN != True:
-			print "Creating menu..."
+			# print "Creating menu..."
 			self.mbSettings = QAction('Settings', self)
 			self.mbSettings.setObjectName("menuButton")
 			self.connect(self.mbSettings, SIGNAL('triggered()'), self.settingsDialog)
@@ -95,7 +97,7 @@ class MainWindow(QMainWindow): # Class for main application
 			mitem.addAction(self.mbBugger)
 		
 		# Creating tabs and using tab widget as a Central widget
-		print "Creating tabs..."
+		# print "Creating tabs..."
 		self.tabs = QTabWidget()
 		self.tabs.TabShape(QTabWidget.Rounded)
 		self.tabs.addTab(self.basicMode(), "Basic") # index = 0
@@ -112,12 +114,12 @@ class MainWindow(QMainWindow): # Class for main application
 		self.tabVisibility()
 		
 		self.connect(self.mapper, SIGNAL("mapped(const QString &)"), self.buttonClicked) # Connects signals to functions.
-		print "Main ready!"
+		# print "Main ready!"
 
 ########## Modes in tabs ##########
 
 	def basicMode(self):
-		print "Creating Basic..."
+		# print "Creating Basic..."
 		widget = QWidget()
 		hbox = QHBoxLayout()
 	
@@ -137,11 +139,11 @@ class MainWindow(QMainWindow): # Class for main application
 		hbox.addWidget(self.sec2mod)
 		widget.setLayout(hbox)
 		
-		print "Basic ready!"
+		# print "Basic ready!"
 		return widget
 
 	def bulbMode(self):
-		print "Creating bulb..."
+		# print "Creating bulb..."
 		widget = QWidget()
 		
 		hbox = QHBoxLayout()
@@ -179,11 +181,11 @@ class MainWindow(QMainWindow): # Class for main application
 		hbox.addLayout(vbox, 0)
 		widget.setLayout(hbox)
 		
-		print "Bulb ready!"
+		# print "Bulb ready!"
 		return widget
 		
 	def timedMode(self):
-		print "Creating timed..."
+		# print "Creating timed..."
 		widget = QWidget()		
 		main = QVBoxLayout()
 		
@@ -251,11 +253,11 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		widget.setLayout(main)
 		
-		print "Timed ready!"
+		# print "Timed ready!"
 		return widget
 		
 	def viewerMode(self):
-		print "Creating viewer..."
+		# print "Creating viewer..."
 		widget = QWidget()
 		hbox = QHBoxLayout()
 		
@@ -295,11 +297,11 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		widget.setLayout(hbox)
 		
-		print "Viewer ready!"
+		# print "Viewer ready!"
 		return widget
 
 	def systemMode(self):
-		print "Creating system..."
+		# print "Creating system..."
 		widget  = QWidget()
 
 		griddy = QGridLayout()
@@ -333,7 +335,7 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		widget.setLayout(griddy)
 		
-		print "System ready!"
+		# print "System ready!"
 		return widget
 
 ######### Timer for Bulb and Timed Modes #########
@@ -851,7 +853,7 @@ class MainWindow(QMainWindow): # Class for main application
 			print "Something wrong in buttons"
 
 	def tabEnabler(self, val): # Enabling/disabling tabs in timed and bulb mode (when process is on, tabs can't be changed).
-		print "Handling tab enbality..."
+		# print "Handling tab enbality..."
 		for i in range(self.tabs.count()):
 			if i != self.tabs.currentIndex():
 				self.tabs.setTabEnabled(i, val)
@@ -859,8 +861,8 @@ class MainWindow(QMainWindow): # Class for main application
 ####### Visibility handling #######
 
 	def buttonVisibility(self): # Button visibility, currently only sec2mod & sec2mod2 for canon
-		print "Setting button visibility..."
-		if CURRENT_REMOTETYPE != "CANON-RC1/RC5":
+		# print "Setting button visibility..."
+		if CURRENT_REMOTETYPE != "CANON-RC1/RC5" or CURRENT_REMOTETYPE != "Minolta_RC3":
 			self.sec2mod.hide()
 			self.sec2mod2.hide()
 		else:
@@ -868,7 +870,7 @@ class MainWindow(QMainWindow): # Class for main application
 			self.sec2mod2.show()
 
 	def tabVisibility(self):
-		print "Setting tab visibility..."
+		# print "Setting tab visibility..."
 		count = self.tabs.count() # Number of tabs, used for failsafe!
 		if USEFULLSCREEN != True and count == 5: # Removing systemMode if not fullscreen
 			self.tabs.removeTab(count-1)
@@ -930,11 +932,16 @@ class MainWindow(QMainWindow): # Class for main application
 		self.cameraGroup.addButton(pentax)
 		cbox.addWidget(pentax)
 		
+		minolta = QRadioButton("Minolta and Sony")
+		self.cameraGroup.addButton(minolta)
+		cbox.addWidget(minolta)
+		
 		# Activating current camera + failsafe to canon
 		if CURRENT_REMOTETYPE == "CANON-RC1/RC5": canon.toggle()
 		elif CURRENT_REMOTETYPE == "NikonDSLR": nikon.toggle()
 		elif CURRENT_REMOTETYPE == "Olympus_RM-1": olympus.toggle()
 		elif CURRENT_REMOTETYPE == "Pentax_RC-F": pentax.toggle()
+		elif CURRENT_REMOTETYPE == "Minolta_RC3": minolta.toggle()
 		else: canon.toggle()
 		
 		vbox.addLayout(cbox, 0)		
@@ -988,11 +995,11 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		self.dialog.setLayout(mainBox)
 		
-		print "Running settings dialog..."
+		# print "Running settings dialog..."
 		self.dialog.exec_()
 		
 	def setSettings(self):
-		print "Save settings..."
+		# print "Save settings..."
 		global CURRENT_REMOTETYPE, TIME2BEEB, USEFULLSCREEN
 		settings = QSettings("pyKake", "pyKake")
 		
@@ -1001,7 +1008,8 @@ class MainWindow(QMainWindow): # Class for main application
 		elif cam.text() == "Nikon": remote = "NikonDSLR"
 		elif cam.text() == "Olympus": remote = "Olympus_RM-1"
 		elif cam.text() == "Pentax and Samsung": remote = "Pentax_RC-F"
-		settings.setValue("settings/camera", remote)
+		elif cam.text() == "Minolta and Sony": remote = "Minolta_RC3"
+ 		settings.setValue("settings/camera", remote)
 		CURRENT_REMOTETYPE = remote
 		
 		timed = self.beebGroup.checkedButton()
@@ -1021,7 +1029,7 @@ class MainWindow(QMainWindow): # Class for main application
 		self.buttonVisibility() # Hiding showing mod2sec buttons for canon
 		self.tabVisibility() # Handling visibility of tabs
 		
-		print "Settings saved."
+		# print "Settings saved."
 		self.dialog.accept()
 
 ########## Other dialogs ##########
@@ -1080,7 +1088,7 @@ class MainWindow(QMainWindow): # Class for main application
 				
 		dialog.setLayout(mainbox)
 		
-		print "Running about dialog..."
+		# print "Running about dialog..."
 		dialog.exec_()
 
 	def helpDialog(self):
@@ -1123,7 +1131,7 @@ class MainWindow(QMainWindow): # Class for main application
 		mainbox.addWidget(tabby)
 		dialog.setLayout(mainbox)
 		
-		print "Running help dialog..."
+		# print "Running help dialog..."
 		dialog.exec_()
 		
 ############ Other classes ############
@@ -1132,6 +1140,7 @@ class ButtonFunctions:
 		if CURRENT_REMOTETYPE == "Olympus_RM-1": digitalCamera().olympus(data)
 		elif CURRENT_REMOTETYPE == "CANON-RC1/RC5": digitalCamera().canon()
 		elif CURRENT_REMOTETYPE == "Pentax_RC-F": digitalCamera().pentax(data)
+		elif CURRENT_REMOTETYPE == "Minolta_RC3" : digitalCamera().minolta() # The new one!
 		else: digitalCamera().oneButtonRemotes(CURRENT_REMOTETYPE)	
 			
 class MiscFunctions:
@@ -1143,30 +1152,30 @@ class MiscFunctions:
 		lircing.wait()
 
 	def readQSettings(self, path, default): # Reading QSettings
-		print "Reading QSettings..."
+		# print "Reading QSettings..."
 		settings = QSettings("pyKake", "pyKake")
 		value = settings.value(path, default) # path == location of the value | default == default value (failback)
 		return value
 	
 	def exitFunction(self): # Exiting the application
-		print "Exit..."
+		# print "Exit..."
 		MiscFunctions().controlLircd("stop")
-		print "Bye Bye!"
+		# print "Bye Bye!"
 		sys.exit()
 	
 	def readFile(self, fileName):
-		print "Reading file..."
+		# print "Reading file..."
 		file = QFile(fileName)
 		
 		if not file.open(QFile.ReadOnly | QFile.Text):
-			print "Problems while loading file."
+			# print "Problems while loading file."
 		
 		data = QTextStream(file)
 		text = data.readAll()
 		return text
 
 	def loadSettings(self): # Reloading settings from conf file at /home/user/.config/pyKake/pyKake.conf
-		print "Settingsloader..."
+		# print "Settingsloader..."
 		global CURRENT_REMOTETYPE, TIME2BEEB, USEFULLSCREEN
 		CURRENT_REMOTETYPE = QVariant(self.readQSettings("settings/camera", "None")).toString()
 		TIME2BEEB = QVariant(self.readQSettings("settings/beebtime", "None")).toString()
@@ -1174,17 +1183,13 @@ class MiscFunctions:
 		 
 class player (QThread):
 	def run(self):
-		print "a"
+		# print "Playing sound..."
 		QThread.__init__(self)
-		print "b"
 		global beebRun
-		print "c"
 		player = gst.element_factory_make("playbin","player")
-		print "d"
 		player.set_property('uri', globURI)
-		print "e"
 		player.set_state(gst.STATE_PLAYING)
-		print "done"
+		# print "Sound: Done"
 				
 class digitalCamera: # This is class where commands from GUI are translated ready to be send to camera
 	def olympus(self,rawdata):
@@ -1200,6 +1205,13 @@ class digitalCamera: # This is class where commands from GUI are translated read
 			cmd = "S"
 		self.remote(cmd)
 
+	def minolta(self): # Minolta should also work for sony too
+		if mod2sec == True:
+			cmd = "two_sec"
+		else:
+			cmd = "one_sec"
+		self.remote(cmd)
+			
 	def pentax(self, data):
 		if data == "bulbon":
 			""" Sending start command in bulb mode """
@@ -1222,7 +1234,7 @@ class digitalCamera: # This is class where commands from GUI are translated read
 
 	# COMMANDING INFRA RED
 	def remote(self, code):
-		print "Shooting..."
+		# print "Shooting..."
 		remote = CURRENT_REMOTETYPE
 		arg = ["/usr/bin/irsend", "send_once", remote, code]
 		shoot = subprocess.Popen (arg, stdin = subprocess.PIPE, stdout = subprocess.PIPE)
@@ -1233,7 +1245,7 @@ class digitalCamera: # This is class where commands from GUI are translated read
 		shoot.wait()
 
 	def bulbPatchPentax(self, state):
-		print "Shooting Pentax"
+		# print "Shooting Pentax"
 		remote = CURRENT_REMOTETYPE
 		code = "Capture"
 		if state == "start":
@@ -1256,22 +1268,22 @@ class digitalCamera: # This is class where commands from GUI are translated read
 ####### Running the Application #######
 
 #app = QApplication(sys.argv) # Currently out of use (since v. 0.7.1), because Pr 1.3 causing problems at the moment (2.11.2010).
-print "Loading settings..."
+# print "Loading settings..."
 MiscFunctions().loadSettings()
 print "Starting Lirc..."
 MiscFunctions().controlLircd("start")
 
-print "Calling Main window..."
+# print "Calling Main window..."
 main = MainWindow()
 
 if USEFULLSCREEN == True:
-	print "Showing window: Fullscreen"
+	# print "Showing window: Fullscreen"
 	main.showFullScreen()
 else:
-	print "Showing window: Normal"
+	# print "Showing window: Normal"
 	main.show()
 
 
-print "Executing the app..."
+# print "Executing the app..."
 app.exec_()
 MiscFunctions().exitFunction()
